.. include:: ../references.txt

.. _dev:

===============
Developer guide
===============

The developer documentation is a collection of notes for Gammapy developers and maintainers.
If something is not covered here, have a look at the very extensive
`Astropy developer documentation <https://docs.astropy.org/en/latest/index_dev.html>`__,
as well. If you want to contribute to Gammapy just use one of the `contact points <https://gammapy.org/contact.html>`__
listed on the Gammapy webpage. Ideally you join directly the #dev channel in the Gammapy Slack.

**Technical setup**

.. toctree::
  :maxdepth: 1

  setup
  dependencies

**Contribution recipes**

.. toctree::
  :maxdepth: 1

  intro
  release

**How To**

.. toctree::
  :maxdepth: 1

  doc_howto
  dev_howto

**Proposals for Improvement of Gammapy**

.. toctree::
  :maxdepth: 1

  pigs/index
